@@ -1,10 +1,9 @@
-/* $Id: client.c,v 0.10 1997/03/17 09:36:17 yoichi 0_6 $
+/* $Id: client.c,v 0.12 1997/08/28 14:35:52 yoichi v0_70 $
  *
  * dhcpcd - DHCP client daemon -
- * Copyright (C) 1996 Yoichi Hariguchi
- *                            (yoichi@fore.com)
+ * Copyright (C) 1996 - 1997 Yoichi Hariguchi <yoichi@fore.com>
  *
- * Dhcpcd is an RFC1541 compliant DHCP client daemon.
+ * dhcpcd is an RFC2131 and RFC1541 compliant DHCP client daemon.
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -47,6 +46,7 @@
 #include "client.h"
 
 extern int BeRFC1541;			/* if 1, Be RFC154 compliant */
+extern char *Hostname;			/* if !NULL, put hostname into DHCP msg */
 
 
 int (*Fsm[MAX_STATES])();		/* finite state machine */
@@ -71,7 +71,8 @@ u_long RebindTime;				/* T2 time (network byte order) */
 
 static u_char *OptPtr[MAXNOPT];	/* array of ptrs to DHCP option element */
 static u_char *OptOffer[MAXNOPT];	/* same as above in DHCPOFFER msg */
-static u_char ClassId[128];		/* class identifier */
+static u_char ClassId[MAXIDCHARS];	/* class identifier */
+static u_char ClientId[MAXIDCHARS];	/* client identifier */
 
 
 void
@@ -91,20 +92,53 @@ classIDsetup(char *id)
 	sprintf(ClassId, "%s %s %s", sname.sysname, sname.release, sname.machine);
 }
 
+void
+clientIDsetup(char *id, char *ifname)
+{
+	struct  ifinfo ifinfo;
+	u_char *s;
+	int		len;
+
+	s = ClientId;
+	*s++ = 61;					/* type value of client identifier */
+
+	if ( id != NULL ) {
+		len = strlen(id);
+		if ( len > sizeof(ClientId) - 4 ) {
+			/* 4: code, len, type, EOS */
+			logQuit("clientIDsetup: too long client ID string");
+		}
+		*s++ = len + 1;			/* 1 for the # field */
+		*s++ = 0;				/* type: string */
+		strcpy(s, id);
+		return;
+	}
+	/* setup default client identifier if id is NULL
+	 */
+	strcpy(ifinfo.ifname, ifname);
+	getIfInfo(&ifinfo);
+	*s++ = 7;					/* length: 6 (MAC Addr) + 1 (# field) */
+	*s++ = ARPHRD_ETHER;		/* type: Ethernet address */
+	bcopy(ifinfo.haddr, s, sizeof(ifinfo.haddr));
+}
+
 void
 dhcpMsgInit(u_char *ifname)
 {
 	struct sockaddr_in	addr;
 
+#if 0
 	/* open and bind socket for receiving
 	 */
 	setSockAddrIn(htons(0), htonl(INADDR_ANY), &addr);
 	openRecvSocket(&addr, &Srecv);
+#endif
 
 	/* open and bind socket for sending
 	 */
 	setSockAddrIn(htons(DHCP_CLIENT_PORT), htonl(INADDR_ANY), &addr);
 	openSendSocket(&addr, &Ssend);
+	Srecv = Ssend;
 }
 
 void
@@ -530,10 +564,21 @@ mkDhcpDiscoverMsg(u_char *haddr, dhcpMessage *msg)
 	*p++ = ntpServers;
 	*p++ = nisDomainName;
 
+	if ( Hostname != NULL ) {
+		int len;
+
+		len = strlen(Hostname);
+		*p++ = hostName;
+		*p++ = len;
+		strncpy(p, Hostname, len);
+		p += len;
+	}
 	*p++ = dhcpClassIdentifier;	/* class identifier */
 	*p++ = strlen(ClassId);
 	strcpy(p, ClassId);
 	p += strlen(ClassId);
+	bcopy(ClientId, p, ClientId[1]+2); /* client identifier */
+	p += ClientId[1] + 2;
 	*p = endOption;				/* end */
 }
 
@@ -600,10 +645,21 @@ mkDhcpRequestMsg(int flag, u_long serverInaddr, u_long leaseTime,
 	*p++ = ntpServers;
 	*p++ = nisDomainName;
 
+	if ( Hostname != NULL ) {
+		int len;
+
+		len = strlen(Hostname);
+		*p++ = hostName;
+		*p++ = len;
+		strncpy(p, Hostname, len);
+		p += len;
+	}
 	*p++ = dhcpClassIdentifier;			/* class identifier */
 	*p++ = strlen(ClassId);
 	strcpy(p, ClassId);
 	p += strlen(ClassId);
+	bcopy(ClientId, p, ClientId[1]+2);	/* client identifier */
+	p += ClientId[1] + 2;
 	*p = endOption;						/* end */
 }
 
@@ -641,6 +697,17 @@ mkDhcpDeclineMsg(int flag, u_long serverInaddr, u_long ciaddr,
 		*((u_int *)p) = ciaddr;
 		p += sizeof(u_int);
 	}
+	if ( Hostname != NULL ) {
+		int len;
+
+		len = strlen(Hostname);
+		*p++ = hostName;
+		*p++ = len;
+		strncpy(p, Hostname, len);
+		p += len;
+	}
+	bcopy(ClientId, p, ClientId[1]+2); /* client identifier */
+	p += ClientId[1] + 2;
 	*p = endOption;				/* end */
 }
 
