@@ -1,10 +1,9 @@
-/* $Id: client.h,v 0.1 1996/08/15 15:19:23 yoichi v0_3 $
+/* $Id: client.h,v 0.2 1997/08/28 14:36:39 yoichi v0_70 $
  *
  * dhcpcd - DHCP client daemon -
- * Copyright (C) 1996 Yoichi Hariguchi
- *                            (yoichi@fore.com)
+ * Copyright (C) 1996 - 1997 Yoichi Hariguchi <yoichi@fore.com>
  *
- * Dhcpcd is an RFC1541 compliant DHCP client daemon.
+ * dhcpcd is an RFC2131 and RFC1541 compliant DHCP client daemon.
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -32,6 +31,16 @@ void	classIDsetup(char *id);
  * returns:  nothing
  */
 
+void	clientIDsetup(char *id, char *ifname);
+/* requests: 'id' pointing to the class identifier string
+ *           'ifname' pointing to the interface name like 'eth0'
+ * effects:  it sets the default client identifier to 'ClientId'
+ *           if 'id' is NULL. Otherwise it sets the string described by
+ *           'id' to 'ClientId'.
+ * modifies: ClientId[]
+ * returns:  nothing
+ */
+
 void	dhcpMsgInit(u_char *ifname);
 /* requests: 'ifname' pointing to the interface name
  * effects:  it opens two sockets 'Srecv' and 'Ssend' for sending/receiving
