@@ -1,10 +1,9 @@
-/* $Id: main.c,v 0.8 1997/03/09 08:02:04 yoichi v0_6 $
+/* $Id: main.c,v 0.10 1997/08/28 14:42:26 yoichi v0_70 $
  *
  * dhcpcd - DHCP client daemon -
- * Copyright (C) 1996 Yoichi Hariguchi
- *                            (yoichi@fore.com)
+ * Copyright (C) 1996 - 1997 Yoichi Hariguchi <yoichi@fore.com>
  *
- * Dhcpcd is an RFC1541 compliant DHCP client daemon.
+ * dhcpcd is an RFC2131 and RFC1541 compliant DHCP client daemon.
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -38,6 +37,7 @@
 #include "error-handler.h"
 #include "daemon.h"
 #include "client.h"
+#include "memory.h"
 
 #define DEFAULT_IF	"eth0"
 
@@ -45,7 +45,9 @@ char *CommandFile = NULL;		/* invoked command file name when dhcpcd
 								 * succeeds in getting an IP address
 								 */
 int	  BeRFC1541 = 0;			/* default is InternetDraft mode */
-static char VersionStr[] = "dhcpcd 0.6\n";
+char *Hostname = NULL;			/* hostname in the DHCP msg for xmit */
+
+static char VersionStr[] = "dhcpcd 0.70\n";
 
 void	usage();
 
@@ -55,9 +57,10 @@ main(argc, argv)
 int argc;
 char *argv[];
 {
-	char ifname[10];			/* interface name */
-	char pidfile[128];			/* file name in which pid is stored */
-	int  killFlag = 0;			/* if 1: kill the running proc and exit */
+	char  ifname[10];			/* interface name */
+	char  pidfile[128];			/* file name in which pid is stored */
+	char *clientId = NULL;		/* ptr to client identifier user specified */
+	int   killFlag = 0;			/* if 1: kill the running proc and exit */
 
 	DebugFlag = 0;				/* default is NON debug mode */
 	srand((u_int)time(NULL));
@@ -81,12 +84,25 @@ char *argv[];
 			  case 'd':
 				DebugFlag = 1;
 				break;
+			  case 'h':
+				if ( *++argv == NULL ) {
+					usage();
+				}
+				Hostname = smalloc(strlen(*argv)+1);
+				strcpy(Hostname, *argv);
+				break;
 			  case 'i':
 				if ( *++argv == NULL ) {
 					usage();
 				}
 				classIDsetup(*argv); /* overwrite class identifier */
 				break;
+			  case 'I':
+				if ( *++argv == NULL ) {
+					usage();
+				}
+				clientId = *argv;
+				break;
 			  case 'k':
 				killFlag = 1;	/* kill running process and exit */
 				break;
@@ -132,6 +148,7 @@ char *argv[];
 	}
 	logOpen("dhcpcd", LOG_PID, LOG_LOCAL0);
 	ifReset(ifname);			/* reset interface, 'Ifbuf' */
+	clientIDsetup(clientId, ifname);
 	dhcpMsgInit(ifname);
 	dhcpClient();
 }
@@ -140,7 +157,7 @@ void
 usage()
 {
 	fflush(stdout);
-	fputs("Usage: dhcpcd [-c filename] [-d] [-i classIdentifier] [-k] [-l leasetime] [ifname]\n",
+	fputs("Usage: dhcpcd [-c filename] [-d] [-i classIdentifier] [-I clientIdentifier] [-k] [-l leasetime] [ifname]\n",
 		  stderr);
 	fflush(NULL);
 	exit(1);
